#include "screen.h"
#include "mem.h"
#include "vcpu.h"
#include "speaker.h"

#include <stdio.h>

int main(int argc, char *argv[])
{
  // Parse argument
  if(argc != 2){
    printf("Usage: %s [rom]\n",argv[0]);
    return 1;
  } else if(!FileExists(argv[1])){
    printf("ROM not found: %s\n",argv[1]);
    return 1;
  }

  // Initialize
  MemInit();
  MemLoadROM(argv[1]);
  ScreenInit(1000,500);
  VCPUInit();
  SpeakerInit();

  // Set game to run at very high FPS (prevent raylib to interfer with emulator CPU frequency)
  SetTargetFPS(VCPU_FREQ*100);

  // Emulator main loop
  while (!WindowShouldClose()){
    VCPUTick();
  }

  // Finish
  SpeakerFinish();
  ScreenClose();

  return 0;
}
